<script setup>
import { getCurrentInstance, ref, computed, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postBlob } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import EditView from './edit.vue'
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-waveSeed';
let currentPage = 1;
let pageSize = 10;
const searchInput = ref("")
const searchParam = ref({
  siteNo: null,
  orderNo: null,
  matnr: null,
  batch: null,
})
const editChild = ref(null)

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

const reviewState = reactive({
  open: false,
  record: null,
  reviewNum: null
});

let tableData = ref([]);
getPage();

const {
  getColumnSearchProps,
  handleResizeColumn,
} = useTableSearch();

const columns = [
  // {
  //   title: formatMessage('db.man_wave_seed.site_id', '站点ID'),
  //   dataIndex: 'siteId$',
  //   width: 140,
  //   ellipsis: true,
  //   ...getColumnSearchProps('siteId$'),
  // },
  {
    title: formatMessage('db.man_wave_seed.site_no', '站点编号'),
    dataIndex: 'siteNo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('siteNo'),
  },
  {
    title: formatMessage('db.man_wave_seed.orderNo', '订单编号'),
    dataIndex: ['orderDetl$', 'orderNo'],
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('orderNo'),
  },
  {
    title: formatMessage('db.man_wave_seed.matnr', '商品编号'),
    dataIndex: ['orderDetl$', 'mat$', 'matnr'],
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('matnr'),
  },
  // {
  //   title: formatMessage('db.man_wave_seed.order_detl_id', '订单明细'),
  //   dataIndex: 'orderDetlId$',
  //   width: 140,
  //   ellipsis: true,
  //   ...getColumnSearchProps('orderDetlId$'),
  // },
  {
    title: formatMessage('db.man_wave_seed.anfme', '数量'),
    dataIndex: 'anfme',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('anfme'),
  },
  {
    title: formatMessage('db.man_wave_seed.workQty', '复核数量'),
    dataIndex: 'workQty',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('workQty'),
  },
  // {
  //   title: formatMessage('db.man_wave_seed.status', '状态'),
  //   dataIndex: 'status$',
  //   width: 140,
  //   ellipsis: true,
  //   ...getColumnSearchProps('status$'),
  // },
  {
    title: formatMessage('db.man_wave_seed.create_time', '添加时间'),
    dataIndex: 'createTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createTime$'),
  },
  {
    title: formatMessage('db.man_wave_seed.create_by', '添加人员'),
    dataIndex: 'createBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createBy$'),
  },
  // {
  //   title: formatMessage('db.man_wave_seed.update_time', '修改时间'),
  //   dataIndex: 'updateTime$',
  //   width: 140,
  //   ellipsis: true,
  //   ...getColumnSearchProps('updateTime$'),
  // },
  // {
  //   title: formatMessage('db.man_wave_seed.update_by', '修改人员'),
  //   dataIndex: 'updateBy$',
  //   width: 140,
  //   ellipsis: true,
  //   ...getColumnSearchProps('updateBy$'),
  // },
  {
    title: formatMessage('db.man_wave_seed.memo', '备注'),
    dataIndex: 'memo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('memo'),
  },

  {
    title: formatMessage('common.operation', '操作'),
    name: 'oper',
    dataIndex: 'oper',
    key: 'oper',
    width: 140,
    fixed: 'right',
  },
];

const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;
  post('/api/waveSeed/page', {
    current: currentPage,
    pageSize: pageSize,
    condition: searchInput.value,
    _param: searchParam.value,
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      tableData.value = data;

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : JSON.parse(JSON.stringify(item));
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/waveSeed/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/waveSeed/export', {}).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

const onPageChange = (page, size) => {
  currentPage = page;
  pageSize = size;
  getPage();
}

function handleTableReload(value) {
  getPage()
}

const handleReview = (record) => {
  reviewState.open = true;
  reviewState.record = record;
  reviewState.reviewNum = 0;
}

const handleReviewOk = () => {
  post('/api/waveSeed/review', {
    waveSeedId: reviewState.record.id,
    reviewNum: reviewState.reviewNum,
  }).then((resp) => {
    let result = resp.data;
    if (result.code === 200) {
      message.success(result.msg);
      reviewState.open = false;
      handleTableReload()
    } else {
      message.error(result.msg);
    }
  })
}

</script>

<script>
export default {
  name: '波次播种'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <div>
        <a-input v-model:value="searchParam.siteNo" :placeholder="formatMessage('page.waveSeed.siteNo.input', '请输入站点编号')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.orderNo" :placeholder="formatMessage('page.waveSeed.orderNo.input', '请输入订单编号')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.matnr" :placeholder="formatMessage('page.waveSeed.matnr.input', '请输入商品编号')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.batch" :placeholder="formatMessage('page.waveSeed.batch.input', '请输入批号')"
          style="width: 140px;margin-right: 10px;" />

        <a-input-search v-model:value="searchInput" :placeholder="formatMessage('page.input', '请输入')"
          style="width: 200px;" @search="onSearch" />
      </div>
      <div class="table-header-right">
        <!-- <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button> -->
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>
    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData.records" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
      :pagination="{ total: tableData.total, onChange: onPageChange }"
      :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="columns" @resizeColumn="handleResizeColumn"
      :loading="state.loading">
      <template #bodyCell="{ column, text, record }">
        <template v-if="column.dataIndex === 'oper'">
          <div style="display: flex;justify-content: space-evenly;">
            <!-- <a-button type="link" primary @click="handleEdit(record)">{{ formatMessage('page.edit', '编辑') }}</a-button> -->
            <a-button type="link" primary @click="handleReview(record)">{{ formatMessage('page.review', '复核')
              }}</a-button>
            <a-button type="link" danger @click="handleDel([record])">{{ formatMessage('page.delete', '删除')
              }}</a-button>
          </div>
        </template>
      </template>
    </a-table>

    <a-modal v-model:open="reviewState.open" :title="formatMessage('page.review', '复核')" @ok="handleReviewOk">
      <div style="margin-bottom: 20px;">
        播种数量：{{ reviewState.record.anfme }}
      </div>
      <div style="display: flex;justify-content: flex-start;align-items: center;">
        实际数量：<a-input-number v-model:value="reviewState.reviewNum" :min="1" :max="reviewState.record.anfme" />
      </div>
    </a-modal>
  </div>
</template>

<style></style>
